unit uVerifyState;
{$INCLUDE 'vfy.inc'}

interface

uses
  SysUtils, Classes, Windows,
  uHashItem;

type
  TVerifyState = (vstFileError, vstLoadingHashFile, vstBuildOutput, vstMatchOutput,
                  vstDupesOutput, vstProgressDone, vstSortingResults,
                  vstWritingResults, vstSortingHashlist, vstComparingHashlists,
                  vstLookingForDupes, vstProcessingFile, vstMatchStats, vstDupesStats
                 );

  TStateChangeObject = class
    private
    protected
    public
    end;

  TStateChangeException = class(TStateChangeObject)
    private
      fExceptionClass: string;
      fExceptionMessage: string;
    public
      constructor Create(E: Exception);
      property ExceptionClass: string read fExceptionClass;
      property ExceptionMessage: string read fExceptionMessage;
    end;

  TStateChangeErrorInFile = class(TStateChangeException)
    private
      fFileName: string;
    public
      constructor Create(E: Exception; const AFileName: string);
      property FileName: string read fFileName;
    end;

  TStateChangeFilename = class(TStateChangeObject)
    private
      fFileName: string;
    public
      constructor Create(const AFileName: string);
      property FileName: string read fFileName;
    end;

  TStateChangeHashItem = class(TStateChangeObject)
    private
      fItem: THashItem;
    public
      constructor Create(const AItem: THashItem);
      property Item: THashItem read fItem;
    end;

  TStateChangeStatistics = class(TStateChangeObject)
    private
      fMatchCount: integer;
      fNewCount: integer;
      fChangedCount: integer;
      fDeletedCount: integer;
      fCopiedCount: integer;
      fRenamedCount: integer;
    public
      constructor Create(const AMatchCount, ANewCount, AChangedCount, ADeletedCount, ACopiedCount, ARenamedCount: integer);
      property MatchCount: integer read fMatchCount;
      property NewCount: integer read fNewCount;
      property ChangedCount: integer read fChangedCount;
      property DeletedCount: integer read fDeletedCount;
      property CopiedCount: integer read fCopiedCount;
      property RenamedCount: integer read fRenamedCount;
    end;

implementation

{ TStateChangeException }

constructor TStateChangeException.Create(E: Exception);
begin
  inherited Create;
  fExceptionClass := E.ClassName;
  fExceptionMessage := E.Message;
end;

{ TStateChangeErrorInFile }

constructor TStateChangeErrorInFile.Create(E: Exception; const AFileName: string);
begin
  inherited Create(E);
  fFileName := AFileName;
end;

{ TStateChangeFilename }

constructor TStateChangeFilename.Create(const AFileName: string);
begin
  inherited Create;
  fFileName := aFileName;
end;

{ TStateChangeHashItem }

constructor TStateChangeHashItem.Create(const AItem: THashItem);
begin
  inherited Create;
  fItem := AItem;
end;

{ TStateChangeStatistics }

constructor TStateChangeStatistics.Create(const AMatchCount, ANewCount, AChangedCount, ADeletedCount, ACopiedCount, ARenamedCount: integer);
begin
  fMatchCount := AMatchCount;
  fNewCount := ANewCount;
  fChangedCount := AChangedCount;
  fDeletedCount := ADeletedCount;
  fCopiedCount := ACopiedCount;
  fRenamedCount := ARenamedCount;
end;

end.
